@@ -23,8 +23,8 @@ else
     rm -rf ./aws-lambda-cpp-$AWS_LAMBDA_CPP_RELEASE
 
     # unpack dependencies
-    tar xzf ./curl-$CURL_VERSION.tar.gz && \
-    tar xzf ./aws-lambda-cpp-$AWS_LAMBDA_CPP_RELEASE.tar.gz
+    tar xzf ./curl-$CURL_VERSION.tar.gz --no-same-owner && \
+    tar xzf ./aws-lambda-cpp-$AWS_LAMBDA_CPP_RELEASE.tar.gz --no-same-owner
 
     (
         # Build Curl
@@ -34,6 +34,7 @@ else
                 --prefix "$ARTIFACTS_DIR" \
                 --disable-shared \
                 --without-ssl \
+                --with-pic \
                 --without-zlib && \
             make && \
             make install
